Module hash_set

Module hash_set 

A hash set implemented as a HashMap where the value is ().

Modules

rayon
rayon-based parallel iterator types for hash sets. You will rarely need to interact with it directly unless you have need to name one of the iterator types.

Structs

Difference
A lazy iterator producing elements in the difference of HashSets.
Drain
A draining iterator over the items of a HashSet.
DrainFilter
A draining iterator over entries of a HashSet which don’t satisfy the predicate f.
HashSet
A hash set implemented as a HashMap where the value is ().
Intersection
A lazy iterator producing elements in the intersection of HashSets.
IntoIter
An owning iterator over the items of a HashSet.
Iter
An iterator over the items of a HashSet.
SymmetricDifference
A lazy iterator producing elements in the symmetric difference of HashSets.
Union
A lazy iterator producing elements in the union of HashSets.