A hash set implemented as a HashMap where the value is ().
Modules
- rayon
- rayon-based parallel iterator types for hash sets. You will rarely need to interact with it directly unless you have need to name one of the iterator types.
Structs
- Difference
- A lazy iterator producing elements in the difference of
HashSets. - Drain
- A draining iterator over the items of a
HashSet. - Drain
Filter - A draining iterator over entries of a
HashSetwhich don’t satisfy the predicatef. - HashSet
- A hash set implemented as a
HashMapwhere the value is(). - Intersection
- A lazy iterator producing elements in the intersection of
HashSets. - Into
Iter - An owning iterator over the items of a
HashSet. - Iter
- An iterator over the items of a
HashSet. - Symmetric
Difference - A lazy iterator producing elements in the symmetric difference of
HashSets. - Union
- A lazy iterator producing elements in the union of
HashSets.